"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.credoKeyTypeIntoSpkiAlgorithm = exports.spkiAlgorithmIntoCredoKeyType = exports.cryptoKeyAlgorithmToCredoKeyType = void 0;
const asn1_ecc_1 = require("@peculiar/asn1-ecc");
const KeyType_1 = require("../../KeyType");
const CredoWebCryptoError_1 = require("../CredoWebCryptoError");
const algorithmIdentifiers_1 = require("../algorithmIdentifiers");
const cryptoKeyAlgorithmToCredoKeyType = (algorithm) => {
    const algorithmName = typeof algorithm === 'string' ? algorithm.toUpperCase() : algorithm.name.toUpperCase();
    switch (algorithmName) {
        case 'ED25519':
            return KeyType_1.KeyType.Ed25519;
        case 'X25519':
            return KeyType_1.KeyType.X25519;
        case 'ECDSA':
            switch (algorithm.namedCurve.toUpperCase()) {
                case 'P-256':
                    return KeyType_1.KeyType.P256;
                case 'P-384':
                    return KeyType_1.KeyType.P384;
                case 'K-256':
                    return KeyType_1.KeyType.K256;
                default:
                    throw new CredoWebCryptoError_1.CredoWebCryptoError(`Unsupported curve for ECDSA: ${algorithm.namedCurve}`);
            }
        default:
            throw new CredoWebCryptoError_1.CredoWebCryptoError(`Unsupported algorithm: ${algorithmName}`);
    }
};
exports.cryptoKeyAlgorithmToCredoKeyType = cryptoKeyAlgorithmToCredoKeyType;
const spkiAlgorithmIntoCredoKeyType = (algorithm) => {
    if (algorithm.isEqual(algorithmIdentifiers_1.ecdsaWithSha256AndP256AlgorithmIdentifier)) {
        return KeyType_1.KeyType.P256;
    }
    else if (algorithm.isEqual(algorithmIdentifiers_1.ecdsaWithSha256AndK256AlgorithmIdentifier)) {
        return KeyType_1.KeyType.K256;
    }
    else if (algorithm.isEqual(algorithmIdentifiers_1.ed25519AlgorithmIdentifier)) {
        return KeyType_1.KeyType.Ed25519;
    }
    else if (algorithm.isEqual(algorithmIdentifiers_1.x25519AlgorithmIdentifier)) {
        return KeyType_1.KeyType.X25519;
    }
    else if (algorithm.isEqual(asn1_ecc_1.ecdsaWithSHA256)) {
        throw new CredoWebCryptoError_1.CredoWebCryptoError(`ecdsa with SHA256 was used. Please specify a curve in algorithm parameters`);
    }
    throw new CredoWebCryptoError_1.CredoWebCryptoError(`Unsupported algorithm: ${algorithm.algorithm}, with params: ${algorithm.parameters ? 'yes' : 'no'}`);
};
exports.spkiAlgorithmIntoCredoKeyType = spkiAlgorithmIntoCredoKeyType;
const credoKeyTypeIntoSpkiAlgorithm = (keyType) => {
    switch (keyType) {
        case KeyType_1.KeyType.Ed25519:
            return algorithmIdentifiers_1.ed25519AlgorithmIdentifier;
        case KeyType_1.KeyType.X25519:
            return algorithmIdentifiers_1.x25519AlgorithmIdentifier;
        case KeyType_1.KeyType.P256:
            return algorithmIdentifiers_1.ecdsaWithSha256AndP256AlgorithmIdentifier;
        case KeyType_1.KeyType.P384:
            return algorithmIdentifiers_1.ecdsaWithSha256AndP384AlgorithmIdentifier;
        case KeyType_1.KeyType.K256:
            return algorithmIdentifiers_1.ecdsaWithSha256AndK256AlgorithmIdentifier;
        default:
            throw new CredoWebCryptoError_1.CredoWebCryptoError(`Unsupported key type: ${keyType}`);
    }
};
exports.credoKeyTypeIntoSpkiAlgorithm = credoKeyTypeIntoSpkiAlgorithm;
//# sourceMappingURL=keyAlgorithmConversion.js.map